@@ -2,11 +2,14 @@ use std::convert::TryInto;
 
 use clap::ArgMatches;
 use miette::Result;
-use mit_commit_message_lints::{external, lints::read_from_toml_or_else_vcs};
+use mit_commit_message_lints::{
+    console::style::to_be_piped,
+    external,
+    lints::read_from_toml_or_else_vcs,
+};
 
 use crate::{current_dir, get_vcs};
-
-pub(crate) fn run_on_match(matches: &ArgMatches) -> Option<Result<()>> {
+pub fn run_on_match(matches: &ArgMatches) -> Option<Result<()>> {
     matches
         .subcommand_matches("lint")
         .filter(|subcommand| subcommand.subcommand_matches("generate").is_some())
@@ -25,7 +28,7 @@ fn run(matches: &ArgMatches) -> Result<()> {
 
     let output_toml: String = read_from_toml_or_else_vcs(&input_toml, &mut vcs)?.try_into()?;
 
-    mit_commit_message_lints::console::to_be_piped(output_toml.trim());
+    to_be_piped(output_toml.trim());
 
     Ok(())
 }
