@@ -4,7 +4,7 @@ use mit_commit_message_lints::external::Vcs;
 
 use crate::{current_dir, get_vcs};
 
-pub(crate) fn run_on_match(matches: &ArgMatches) -> Option<Result<()>> {
+pub fn run_on_match(matches: &ArgMatches) -> Option<Result<()>> {
     matches
         .subcommand_matches("relates-to")
         .filter(|subcommand| subcommand.subcommand_matches("template").is_some())
